@@ -1,3 +1,3 @@
 ''' Djheroku for populating Heroku environment variables to Django '''
 from djheroku.conf import (sendgrid, mailgun, cloudant, memcachier, identity,
-                           social)
+                           social, allowed_hosts)
